==> gclcvs_2.7.0-26.tar.gz: gclcvs-2.7.0/cmpnew/sys-proclaim.lisp <==

(IN-PACKAGE "COMPILER") 

(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MLIN)) 
(PROCLAIM '(FTYPE (FUNCTION (T) T)  COPY-ARRAY COPY-INFO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) FIXNUM)  PUSH-ARRAY)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM T) FIXNUM) BSEARCHLEQ)) 
(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) F-TYPE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) FIXNUM) ANALYZE-REGS PROCLAIMED-ARGD
            ANALYZE-REGS1)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) C2FLET C2LABELS C2COMPILER-LET C2IF
            WT-INLINE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) C1DM-VL C1DM-V C2DM C2RETURN-FROM
            C2APPLY-OPTIMIZE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) *) T3DEFUN-AUX)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) T) WT-INLINE-INTEGER WT-INLINE-CHARACTER
            ADD-FUNCTION-PROCLAMATION WT-INLINE-LONG-FLOAT
            WT-INLINE-SHORT-FLOAT ADD-FUNCTION-DECLARATION CJF
            CHECK-VDECL CJT C1MAP-FUNCTIONS AND-FORM-TYPE
            CHECK-FORM-TYPE C2MAPCAR C2FUNCALL-SFUN C2MAPC C2MAPCAN
            C2LET FIX-DOWN-ARGS SET-VAR WT-IF-PROCLAIMED TOO-MANY-ARGS
            TOO-FEW-ARGS ASSIGN-DOWN-VARS C2MULTIPLE-VALUE-BIND BOOLE3
            C1DM CMP-EXPAND-MACRO C2CASE SUBLIS1-INLINE T3DEFCFUN
            GET-INLINE-INFO C1STRUCTURE-REF1 C2PRINC CAN-BE-REPLACED*
            ADD-FAST-LINK INLINE-TYPE-MATCHES C2LET* C2TAGBODY C2GO
            C2PROGV WT-INLINE-COND WT-INLINE-FIXNUM)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T) T3DEFUN-VARARG T3DEFUN-NORMAL
            C2CALL-GLOBAL C1MAKE-VAR WT-GLOBAL-ENTRY
            C2CALL-UNKNOWN-GLOBAL MY-CALL C2STRUCTURE-REF C2SWITCH)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T) T) T3DEFUN-LOCAL-ENTRY T3DEFUN
            T2DEFUN T2DEFENTRY T3DEFENTRY
            C1APPLY-OPTIMIZE C2STRUCTURE-SET)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) T) T3LOCAL-DCFUN T3LOCAL-FUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T) T) DEFSYSFUN T2DEFMACRO T3DEFMACRO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) WT-SIMPLE-CALL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T *) T) INLINE-ARGS C2FUNCALL C2LAMBDA-EXPR)) 
(PROCLAIM '(FTYPE (FUNCTION NIL *) WT-FASD-DATA-FILE WT-DATA-FILE)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) INIT-ENV WT-NEXT-VAR-ARG WT-FIRST-VAR-ARG
            WT-DATA-BEGIN WT-DATA-END C1NIL TAIL-RECURSION-POSSIBLE
            PRINT-CURRENT-FORM CCB-VS-PUSH WFS-ERROR CVS-PUSH WT-CVARS
            C1T INC-INLINE-BLOCKS WT-C-PUSH ADD-LOAD-TIME-SHARP-COMMA
            RESET-TOP VS-PUSH BABOON CLOSE-INLINE-BLOCKS)) 
(PROCLAIM '(FTYPE (FUNCTION (*) *) INLINE-BOOLE3)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) T1EXPR CMP-TOPLEVEL-EVAL SET-LOC CMP-EVAL
            T1EVAL-WHEN C2EXPR WT-LOC WT-FIXNUM-LOC C2PROGN
            WT-CHARACTER-LOC WT-LONG-FLOAT-LOC WT-SHORT-FLOAT-LOC C2AND
            C2OR WT-TO-STRING)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) MAKE-FUN LIST-INLINE LIST*-INLINE WT-CLINK
            FCALLN-INLINE MAKE-BLK CS-PUSH MAKE-VAR MAKE-TAG MAKE-INFO)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) VAR-REP-LOC TAG-LABEL C1BOOLE3 TAG-UNWIND-EXIT
            SCH-GLOBAL TAG-VAR C1ASH-CONDITION TAG-SWITCH C1ASH
            ARGS-CAUSE-SIDE-EFFECT WT-VV C1LENGTH WT-CAR ADD-CONSTANT
            WT-CDR WT-CADR VAR-NAME GET-ARG-TYPES VAR-REF WT-VS-BASE
            GET-RETURN-TYPE VAR-REF-CCB GET-LOCAL-ARG-TYPES VAR-LOC
            GET-LOCAL-RETURN-TYPE VAR-TYPE C1ADD-GLOBALS VAR-REGISTER
            C1FLET C1LABELS WT-LIST C1MACROLET FIXNUM-LOC-P
            INFO-CHANGED-VARS CHARACTER-LOC-P INFO-REFERRED-VARS
            LONG-FLOAT-LOC-P INFO-TYPE VERIFY-DATA-VECTOR
            SHORT-FLOAT-LOC-P INFO-SP-CHANGE FUN-P INFO-VOLATILE
            C1LOCAL-CLOSURE C1LOCAL-FUN CMP-MACRO-FUNCTION OBJECT-TYPE
            PROCLAIM RESET-INFO-TYPE C1MAPCAR PROCLAMATION C1MAPLIST
            WT-DATA-PACKAGE-OPERATION DEFAULT-INIT C1MAPC
            FASD-EVALD_FORMS C1MAPL PUSH-ARGS WT-H1 FASD-FILEPOS
            T1ORDINARY PUSH-ARGS-LISPCALL FASD-TABLE_LENGTH C1MAPCAN
            NEED-TO-SET-VS-POINTERS FASD-STREAM CHECK-VREF C1MAPCON
            FASD-TABLE T1PROGN FASD-EOF CHECK-DOWNWARD C1ECASE
            FASD-DIRECTION WT-VS C1VREF SYSTEM:UNDEF-COMPILER-MACRO
            FASD-PACKAGE UNWIND-NO-EXIT FASD-INDEX CLINK FUN-NAME
            C1MULTIPLE-VALUE-CALL FUN-REF VARARG-P FUN-REF-CCB MAXARGS
            C1MULTIPLE-VALUE-PROG1 C2DM-RESERVE-VL FUN-CFUN
            DECLARATION-TYPE C2DM-RESERVE-V FUN-LEVEL ADD-OBJECT
            C1PSETQ C1VALUES C2BIND C2VALUES C2VAR-KIND VAR-P
            C1MULTIPLE-VALUE-SETQ C2FUNCALL-AUX WT-VAR-DECL
            UNDEFINED-VARIABLE C1MULTIPLE-VALUE-BIND C1FUNOB
            C1DOWNWARD-FUNCTION WT-FUNCTION-LINK SET-UP-VAR-CVS
            C2DOWNWARD-FUNCTION WT-FUNCALL-C WT-DOWNWARD-CLOSURE-MACRO
            SAVE-FUNOB CMP-MACROEXPAND PARSE-CVSPECS THE-PARAMETER
            CMP-MACROEXPAND-1 WT-DOWN T1DEFUN C1DM-BAD-KEY T1DEFMACRO
            T1CLINES T1DEFCFUN T1DEFENTRY T1DEFLA C1QUOTE C1FUNCTION
            T2ORDINARY C2FUNCTION NAME-TO-SD C1PROGN WT1 T2DECLARE
            C1THE REP-TYPE C1EVAL-WHEN C1DECLARE C1VAR C1COMPILER-LET
            C1FMLA-CONSTANT T3CLINES WT-SYMBOL-FUNCTION ADD-SYMBOL
            WT-VS* FLAGS-POS INLINE-POSSIBLE CTOP-WRITE C1CATCH C1EXPR
            SAVE-AVMA T1DEFINE-STRUCTURE C1UNWIND-PROTECT AET-C-TYPE
            C1THROW WT-CCB-VS INLINE-BOOLE3-STRING C1STRUCTURE-REF
            SET-PUSH-CATCH-FRAME C1BLOCK RESULT-TYPE GET-INCLUDED
            C1STRUCTURE-SET C1RETURN-FROM CONS-TO-LISTA C2LOCATION
            C1SHARP-COMMA C2EXPR* VAR-KIND C1DEFINE-STRUCTURE ADD-REG1
            CONSTANT-FOLD-P C1PRINC ADD-LOOP-REGISTERS REPLACE-CONSTANT
            C2TAGBODY-CCB INLINE-TYPE C1TERPRI C2TAGBODY-CLB
            WRITE-BLOCK-OPEN C1APPLY C2TAGBODY-LOCAL C2TAGBODY-BODY
            C1LET BLK-P WT-SWITCH-CASE C1LET* C1FUNCALL FIX-OPT
            C2GO-CCB C1RPLACA C2GO-CLB C1STACK-LET C1IF C2RPLACA
            TYPE-FILTER C2GO-LOCAL C1RPLACD C2VAR C1TAGBODY C2RPLACD
            FUNCTION-RETURN-TYPE BLK-NAME C1SETQ C1MEMQ BLK-REF C1GO
            C1AND C1MEMBER BLK-REF-CLB C1PROGV BLK-REF-CCB C1ASSOC
            BLK-EXIT VOLATILE BLK-VALUE-TO-GO TAG-P C1GET BLK-VAR
            C1SWITCH C1OR C2GET INFO-P C1NTH-CONDITION NAME-SD1
            REGISTER C1NTH C1NTHCDR-CONDITION PUSH-DATA-INCF C1NTHCDR
            WT-DATA1 TAG-NAME C1RPLACA-NTHCDR TAG-REF C1LIST-NTH
            TAG-REF-CLB SET-RETURN FUNCTION-ARG-TYPES TAG-REF-CCB
            SET-TOP C1BOOLE-CONDITION SCH-LOCAL-FUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) C1BODY C2DECL-BODY C2BLOCK-LOCAL
            C1SYMBOL-FUN C2RETURN-LOCAL C2BLOCK WT-INLINE-LOC)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) WT-CVAR C1LAMBDA-EXPR CMPERR WT-COMMENT
            CMPWARN CMPNOTE C1CASE ADD-INIT UNWIND-EXIT WT-INTEGER-LOC
            FAST-LINK-PROCLAIMED-TYPE-P)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) VAR-REP-EQ PROCLAIM-VAR CO1LDB SET-JUMP-TRUE CO1EQL
            CO1SPECIAL-FIX-DECL CO1TYPEP WT-FIXNUM-VALUE CO1SCHAR
            WT-CHARACTER-VALUE CO1CONS WT-LONG-FLOAT-VALUE CO1READ-BYTE
            WT-SHORT-FLOAT-VALUE CO1READ-CHAR CO1WRITE-BYTE C1DECL-BODY
            CO1WRITE-CHAR SET-VS CO1VECTOR-PUSH
            COMPILER-CLEAR-COMPILER-PROPERTIES TYPE-AND
            PUSH-CHANGED-VARS C2CALL-LOCAL MAYBE-EVAL C2CALL-LAMBDA
            C2DM-BIND-VL CO1SUBLIS C2PSETQ CMPFIX-ARGS
            C2LAMBDA-EXPR-WITH-KEY MAKE-INLINE-STRING
            MULTIPLE-VALUE-CHECK C2LAMBDA-EXPR-WITHOUT-KEY
            CHECK-FNAME-ARGS COMPILER-DEF-HOOK INLINE-PROC
            C2MULTIPLE-VALUE-CALL SET-BDS-BIND C2MULTIPLE-VALUE-PROG1
            C2DM-BIND-LOC ADD-DEBUG-INFO C2DM-BIND-INIT
            RESULT-TYPE-FROM-ARGS C2BIND-LOC C2BIND-INIT WT-REQUIREDS
            C2MULTIPLE-VALUE-SETQ WT-V*-MACROS SET-JUMP-FALSE
            WT-MAKE-DCLOSURE UNWIND-BDS SHIFT>> SHIFT<< ADD-ADDRESS
            COERCE-LOC ARGS-INFO-CHANGED-VARS C2BLOCK-CCB T2SHARP-COMMA
            C2BLOCK-CLB C1CONSTANT-VALUE WT-VAR C1LAMBDA-FUN
            WT-MAKE-CCLOSURE C1ARGS SYSTEM::ADD-DEBUG C1FMLA C2CATCH
            GET-INLINE-LOC CO1CONSTANT-FOLD C2EXPR-TOP C2RETURN-CCB
            NEED-TO-PROTECT C1EXPR* C2UNWIND-PROTECT C2RETURN-CLB
            SET-DBIND C1SETQ1 C2THROW STRUCT-TYPE-OPT FAST-READ
            JUMPS-TO-P CFAST-WRITE COERCE-LOC-STRUCTURE-REF
            CAN-BE-REPLACED C2EXPR-TOP* C1PROGN* CO1STRUCTURE-PREDICATE
            C2APPLY CONVERT-CASE-TO-SWITCH TYPE>= C2STACK-LET C2SETQ
            C2MEMBER!2 C2ASSOC!2 ADD-INFO ARGS-INFO-REFERRED-VARS
            C2LIST-NTH-IMMEDIATE))

==> gclcvs_2.7.0-36.tar.gz: gclcvs-2.7.0/cmpnew/sys-proclaim.lisp <==

(IN-PACKAGE "COMPILER") 

(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) DASH-TO-UNDERSCORE-INT))
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) C-FUNCTION-NAME))
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MLIN)) 
(PROCLAIM '(FTYPE (FUNCTION (T) T)  COPY-ARRAY COPY-INFO DASH-TO-UNDERSCORE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) FIXNUM)  PUSH-ARRAY)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM T) FIXNUM) BSEARCHLEQ)) 
(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) F-TYPE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) FIXNUM) ANALYZE-REGS PROCLAIMED-ARGD
            ANALYZE-REGS1)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) C2FLET C2LABELS C2COMPILER-LET C2IF
            WT-INLINE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) C1DM-VL C1DM-V C2DM C2RETURN-FROM
            C2APPLY-OPTIMIZE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) *) T3DEFUN-AUX)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) T) WT-INLINE-INTEGER WT-INLINE-CHARACTER
            ADD-FUNCTION-PROCLAMATION WT-INLINE-LONG-FLOAT
            WT-INLINE-SHORT-FLOAT ADD-FUNCTION-DECLARATION CJF
            CHECK-VDECL CJT C1MAP-FUNCTIONS AND-FORM-TYPE
            CHECK-FORM-TYPE C2MAPCAR C2FUNCALL-SFUN C2MAPC C2MAPCAN
            C2LET FIX-DOWN-ARGS SET-VAR WT-IF-PROCLAIMED TOO-MANY-ARGS
            TOO-FEW-ARGS ASSIGN-DOWN-VARS C2MULTIPLE-VALUE-BIND BOOLE3
            C1DM CMP-EXPAND-MACRO C2CASE SUBLIS1-INLINE T3DEFCFUN
            GET-INLINE-INFO C1STRUCTURE-REF1 C2PRINC CAN-BE-REPLACED*
            ADD-FAST-LINK WT-MAKE-CCLOSURE MAKE-INLINE-STRING INLINE-TYPE-MATCHES
	    C2LET* C2TAGBODY C2GO C2PROGV WT-INLINE-COND WT-INLINE-FIXNUM)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T) T3DEFUN-VARARG T3DEFUN-NORMAL
            C2CALL-GLOBAL C1MAKE-VAR WT-GLOBAL-ENTRY
            C2CALL-UNKNOWN-GLOBAL MY-CALL C2STRUCTURE-REF C2SWITCH)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T) T) T3DEFUN-LOCAL-ENTRY T3DEFUN
            T2DEFUN T2DEFENTRY T3DEFENTRY
            C1APPLY-OPTIMIZE C2STRUCTURE-SET)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) T) T3LOCAL-DCFUN T3LOCAL-FUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T) T) DEFSYSFUN T2DEFMACRO T3DEFMACRO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) WT-SIMPLE-CALL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T *) T) INLINE-ARGS C2FUNCALL C2LAMBDA-EXPR)) 
(PROCLAIM '(FTYPE (FUNCTION NIL *) WT-FASD-DATA-FILE WT-DATA-FILE)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) INIT-ENV WT-NEXT-VAR-ARG WT-FIRST-VAR-ARG
            WT-DATA-BEGIN WT-DATA-END C1NIL TAIL-RECURSION-POSSIBLE
            PRINT-CURRENT-FORM CCB-VS-PUSH WFS-ERROR CVS-PUSH WT-CVARS
            C1T INC-INLINE-BLOCKS WT-C-PUSH ADD-LOAD-TIME-SHARP-COMMA
            RESET-TOP VS-PUSH BABOON CLOSE-INLINE-BLOCKS)) 
(PROCLAIM '(FTYPE (FUNCTION (*) *) INLINE-BOOLE3)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) T1EXPR CMP-TOPLEVEL-EVAL SET-LOC CMP-EVAL
            T1EVAL-WHEN C2EXPR WT-LOC WT-FIXNUM-LOC C2PROGN
            WT-CHARACTER-LOC WT-LONG-FLOAT-LOC WT-SHORT-FLOAT-LOC C2AND
            C2OR WT-TO-STRING)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) MAKE-FUN LIST-INLINE LIST*-INLINE WT-CLINK
            FCALLN-INLINE MAKE-BLK CS-PUSH MAKE-VAR MAKE-TAG MAKE-INFO)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) VAR-REP-LOC TAG-LABEL C1BOOLE3 TAG-UNWIND-EXIT
            SCH-GLOBAL TAG-VAR C1ASH-CONDITION TAG-SWITCH C1ASH
            ARGS-CAUSE-SIDE-EFFECT WT-VV C1LENGTH WT-CAR ADD-CONSTANT
            WT-CDR WT-CADR VAR-NAME GET-ARG-TYPES VAR-REF WT-VS-BASE
            GET-RETURN-TYPE VAR-REF-CCB GET-LOCAL-ARG-TYPES VAR-LOC
            GET-LOCAL-RETURN-TYPE VAR-TYPE C1ADD-GLOBALS VAR-REGISTER
            C1FLET C1LABELS WT-LIST C1MACROLET FIXNUM-LOC-P
            INFO-CHANGED-VARS CHARACTER-LOC-P INFO-REFERRED-VARS
            LONG-FLOAT-LOC-P INFO-TYPE VERIFY-DATA-VECTOR
            SHORT-FLOAT-LOC-P INFO-SP-CHANGE FUN-P INFO-VOLATILE
            C1LOCAL-CLOSURE C1LOCAL-FUN CMP-MACRO-FUNCTION OBJECT-TYPE
            PROCLAIM RESET-INFO-TYPE C1MAPCAR PROCLAMATION C1MAPLIST
            WT-DATA-PACKAGE-OPERATION DEFAULT-INIT C1MAPC
            FASD-EVALD_FORMS C1MAPL PUSH-ARGS WT-H1 FASD-FILEPOS
            T1ORDINARY PUSH-ARGS-LISPCALL FASD-TABLE_LENGTH C1MAPCAN
            NEED-TO-SET-VS-POINTERS FASD-STREAM CHECK-VREF C1MAPCON
            FASD-TABLE T1PROGN FASD-EOF CHECK-DOWNWARD C1ECASE
            FASD-DIRECTION WT-VS C1VREF SYSTEM:UNDEF-COMPILER-MACRO
            FASD-PACKAGE UNWIND-NO-EXIT FASD-INDEX CLINK FUN-NAME
            C1MULTIPLE-VALUE-CALL FUN-REF VARARG-P FUN-REF-CCB MAXARGS
            C1MULTIPLE-VALUE-PROG1 C2DM-RESERVE-VL FUN-CFUN
            DECLARATION-TYPE C2DM-RESERVE-V FUN-LEVEL ADD-OBJECT
            C1PSETQ C1VALUES C2BIND C2VALUES C2VAR-KIND VAR-P
            C1MULTIPLE-VALUE-SETQ C2FUNCALL-AUX WT-VAR-DECL
            UNDEFINED-VARIABLE C1MULTIPLE-VALUE-BIND C1FUNOB
            C1DOWNWARD-FUNCTION WT-FUNCTION-LINK SET-UP-VAR-CVS
            C2DOWNWARD-FUNCTION WT-FUNCALL-C WT-DOWNWARD-CLOSURE-MACRO
            SAVE-FUNOB CMP-MACROEXPAND PARSE-CVSPECS THE-PARAMETER
            CMP-MACROEXPAND-1 WT-DOWN T1DEFUN C1DM-BAD-KEY T1DEFMACRO
            T1CLINES T1DEFCFUN T1DEFENTRY T1DEFLA C1QUOTE C1FUNCTION
            T2ORDINARY C2FUNCTION NAME-TO-SD C1PROGN WT1 T2DECLARE
            C1THE REP-TYPE C1EVAL-WHEN C1DECLARE C1VAR C1COMPILER-LET
            C1FMLA-CONSTANT T3CLINES WT-SYMBOL-FUNCTION ADD-SYMBOL
            WT-VS* FLAGS-POS INLINE-POSSIBLE CTOP-WRITE C1CATCH C1EXPR
            SAVE-AVMA T1DEFINE-STRUCTURE C1UNWIND-PROTECT ADD-ADDRESS AET-C-TYPE
            C1THROW WT-CCB-VS INLINE-BOOLE3-STRING C1STRUCTURE-REF
            SET-PUSH-CATCH-FRAME C1BLOCK RESULT-TYPE GET-INCLUDED
            C1STRUCTURE-SET C1RETURN-FROM CONS-TO-LISTA C2LOCATION
            C1SHARP-COMMA C2EXPR* VAR-KIND C1DEFINE-STRUCTURE ADD-REG1
            CONSTANT-FOLD-P C1PRINC ADD-LOOP-REGISTERS REPLACE-CONSTANT
            C2TAGBODY-CCB INLINE-TYPE C1TERPRI C2TAGBODY-CLB
            WRITE-BLOCK-OPEN C1APPLY C2TAGBODY-LOCAL C2TAGBODY-BODY
            C1LET BLK-P WT-SWITCH-CASE C1LET* C1FUNCALL FIX-OPT
            C2GO-CCB C1RPLACA C2GO-CLB C1STACK-LET C1IF C2RPLACA
            TYPE-FILTER C2GO-LOCAL C1RPLACD C2VAR C1TAGBODY C2RPLACD
            FUNCTION-RETURN-TYPE BLK-NAME C1SETQ C1MEMQ BLK-REF C1GO
            C1AND C1MEMBER BLK-REF-CLB C1PROGV BLK-REF-CCB C1ASSOC
            BLK-EXIT VOLATILE BLK-VALUE-TO-GO TAG-P C1GET BLK-VAR
            C1SWITCH C1OR C2GET INFO-P C1NTH-CONDITION NAME-SD1
            REGISTER C1NTH C1NTHCDR-CONDITION PUSH-DATA-INCF C1NTHCDR
            WT-DATA1 TAG-NAME C1RPLACA-NTHCDR TAG-REF C1LIST-NTH
            TAG-REF-CLB SET-RETURN FUNCTION-ARG-TYPES TAG-REF-CCB
            SET-TOP C1BOOLE-CONDITION SCH-LOCAL-FUN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) C1BODY C2DECL-BODY C2BLOCK-LOCAL
            C1SYMBOL-FUN C2RETURN-LOCAL C2BLOCK WT-INLINE-LOC)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) WT-CVAR C1LAMBDA-EXPR CMPERR WT-COMMENT
            CMPWARN CMPNOTE C1CASE ADD-INIT UNWIND-EXIT WT-INTEGER-LOC
            FAST-LINK-PROCLAIMED-TYPE-P)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) VAR-REP-EQ PROCLAIM-VAR CO1LDB SET-JUMP-TRUE CO1EQL
            CO1SPECIAL-FIX-DECL CO1TYPEP WT-FIXNUM-VALUE CO1SCHAR
            WT-CHARACTER-VALUE CO1CONS WT-LONG-FLOAT-VALUE CO1READ-BYTE
            WT-SHORT-FLOAT-VALUE CO1READ-CHAR CO1WRITE-BYTE C1DECL-BODY
            CO1WRITE-CHAR SET-VS CO1VECTOR-PUSH
            COMPILER-CLEAR-COMPILER-PROPERTIES TYPE-AND
            PUSH-CHANGED-VARS C2CALL-LOCAL MAYBE-EVAL C2CALL-LAMBDA
            C2DM-BIND-VL CO1SUBLIS C2PSETQ CMPFIX-ARGS
            C2LAMBDA-EXPR-WITH-KEY MULTIPLE-VALUE-CHECK C2LAMBDA-EXPR-WITHOUT-KEY
            CHECK-FNAME-ARGS COMPILER-DEF-HOOK INLINE-PROC
            C2MULTIPLE-VALUE-CALL SET-BDS-BIND C2MULTIPLE-VALUE-PROG1
            C2DM-BIND-LOC ADD-DEBUG-INFO C2DM-BIND-INIT
            RESULT-TYPE-FROM-ARGS C2BIND-LOC C2BIND-INIT WT-REQUIREDS
            C2MULTIPLE-VALUE-SETQ WT-V*-MACROS SET-JUMP-FALSE
            WT-MAKE-DCLOSURE UNWIND-BDS SHIFT>> SHIFT<<
            COERCE-LOC ARGS-INFO-CHANGED-VARS C2BLOCK-CCB T2SHARP-COMMA
            C2BLOCK-CLB C1CONSTANT-VALUE WT-VAR C1LAMBDA-FUN
            C1ARGS SYSTEM::ADD-DEBUG C1FMLA C2CATCH
            GET-INLINE-LOC CO1CONSTANT-FOLD C2EXPR-TOP C2RETURN-CCB
            NEED-TO-PROTECT C1EXPR* C2UNWIND-PROTECT C2RETURN-CLB
            SET-DBIND C1SETQ1 C2THROW STRUCT-TYPE-OPT FAST-READ
            JUMPS-TO-P CFAST-WRITE COERCE-LOC-STRUCTURE-REF
            CAN-BE-REPLACED C2EXPR-TOP* C1PROGN* CO1STRUCTURE-PREDICATE
            C2APPLY CONVERT-CASE-TO-SWITCH TYPE>= C2STACK-LET C2SETQ
            C2MEMBER!2 C2ASSOC!2 ADD-INFO ARGS-INFO-REFERRED-VARS
            C2LIST-NTH-IMMEDIATE))
